drop table vcp_case;
drop table vcp_phase;
drop table vcp_dimension;
drop table vcp_experience;
drop table vcp_approach;
drop table vcp_subteam;

create table vcp_case (
  cid INT not null primary key,
  name VARCHAR(64) not null,
  phase INT not null,
  coordinator INT not null,
  taskman INT default -1,
  gatekeeper INT default -1,
  integrator INT default -1
);

create table vcp_phase (
  phase INT not null primary key,
  next INT not null,
  text TEXT not null,
  sop VARCHAR(64)
);

create table vcp_dimension (
  did INT not null auto_increment,
  cid INT not null,
  vid INT not null,
  uid INT not null,
  description TEXT not null,
  rationale TEXT,
  priority ENUM('high', 'medium', 'low'),
  integrated BOOL default 1,

  primary key (did, vid)
);

create table vcp_experience (
  did INT not null,
  uid INT not null,
  vid INT not null auto_increment,
  knowledge TEXT not null,
  source TEXT not null,

  primary key (did, uid, vid)
);

create table vcp_approach (
  did INT not null,
  vid INT not null,
  lead_uid INT default -1,
  description TEXT,
  deadline VARCHAR(64),
  solution_nid INT default -1,
  	
  primary key (did, vid)
);

create table vcp_subteam (
  did INT not null,
  uid INT not null,
  vid INT not null,

  primary key (did, uid, vid)
);

insert into vcp_case (
  cid, name, phase, coordinator) 
values (
  1, 'Reindeer Flu', 11, 221
);

insert into vcp_phase  values (
  11, 12, 
  '<ul><li><b>Process coordinator</b>: introduce themself; communicate case to team; introduce individual problem map</li></ul>', 
  'wiki/Special:Objective/Communicate_Information_to_Team'
);
insert into vcp_phase  values (
  12, 13, 
  '<ul><li><b>Team members</b>: complete <a href="/individual-problem-map">individual problem maps</a></li></ul>', 
  'wiki/Procedure:Complete_Individual_Problem_Map'
);
insert into vcp_phase  values (
  13, 21, 
  '<ul><li><b>Process coordinator</b>: organize team meeting; create draft <a href="/integrated-problem-map">integrated problem map</a></li></ul>', 
  'wiki/Procedure:Create_Integrated_Problem_Map'
);
insert into vcp_phase  values (
  21, 22, 
  '<ul><li><b>Process coordinator</b>: welcome</li><li><b>Team</b>: introductions; discuss and agree <a href="/integrated-problem-map">integrated problem map</a></li></ul>', 
  'wiki/Procedure:Create_Integrated_Problem_Map'
);
insert into vcp_phase  values (
  22, 31, 
  '<ul><li><b>Process coordinator</b>: lay out timeline; reference <a href="/vcp-norms">process norms</a></li><li><b>Team</b>: agree <a href="/og/users/818/faces">project roles</a></li></ul>', 
  'wiki/Procedure:Agree_Project_Roles'
);
insert into vcp_phase  values (
  31, 32, 
  '<ul><li><b>Team members</b>: complete <a href="/individual-experience-matrix">individual experience matrix</a></li></ul>', 
  'wiki/Procedure:Complete_Individual_Experience_Matrix'
);
insert into vcp_phase  values (
  32, 41, 
  '<ul><li><b>Process coordinator</b>: organize team meeting; generate experience slides (from <a href="/accountability-matrix">accountability matrix</a>)</li></ul>', 
  'wiki/Procedure:Complete_Project_Plan_Accountability_Matrix'
);
insert into vcp_phase  values (
  41, 42, 
  '<ul><li><b>Process coordinator</b>: reference <a href="/vcp-discussions">discussion norms</a>; introduce the problem dimension solution template</li><li><b>Team</b>: discuss individual experiences (by dimension)</li></ul>', 
  null
);
insert into vcp_phase  values (
  42, 43,
  '<ul><li><b>Team</b>: discuss and agree subteams</li><li><b>Case planner</b>: complete <a href="/accountability-matrix">accountability matrix</a></li></ul>', 
  'wiki/Procedure:Complete_Project_Plan_Accountability_Matrix'
);
insert into vcp_phase  values (
  43, 51, 
  '<ul><li><b>Case planner</b>: generate empty solution pages (from <a href="/accountability-matrix">accountability matrix</a>)</li></ul>', 
  'wiki/Procedure:Complete_Project_Plan_Accountability_Matrix'
);
insert into vcp_phase  values (
  51, 52, 
  '<ul><li><b>Gatekeeper</b>: monitor progress</li><li><b>Subteams</b>: develop solutions</li><li><b>Team members</b>: comment on others solutions', 
  'wiki/Procedure:Create_Problem_Dimension_Solution'
);
insert into vcp_phase  values (
  52, 61, 
  '<ul><li><b>Subteams</b>: create solution presentations</li><li><b>Integrator</b>: begin integration</li></ul>', 
  'wiki/Procedure:Create_Presentation_for_SL_Screen'
);
insert into vcp_phase  values (
  61, 71, 
  '<ul><li><b>Subteams</b>: present solutions and discuss</li></ul>', 
  'wiki/Procedure:Create_Presentation_for_SL_Screen'
);
insert into vcp_phase  values (
  71, 81, 
  '<ul><li><b>Integrator</b>: integrate and deliver final solution</li></ul>', 
  null
);

